# -*- coding: utf-8 -*-
u"""
Examples for the ``sparseig`` module.

``sparseig`` - Large Scale Eigenproblems

This module provides functions for computing **some** eigenvalues and
eigenvectors of large-scale (sparse) standard and generalized eigenvalue
problems.
It provides functions for:

    solution of symmetric eigenvalue problems;

    solution of nonsymmetric eigenvalue problems;

    solution of generalized symmetric-definite eigenvalue problems;

    solution of generalized nonsymmetric eigenvalue problems;

    solution of polynomial eigenvalue problems;

    partial singular value decomposition.

Functions are provided for both `real` and `complex` data.

ARPACK Functions
~~~~~~~~~~~~~~~~
The functions in this module whose names do not contain substring
'_feast_' have all been derived from the ARPACK software suite (see
Lehoucq `et al.` (1998)), a collection of Fortran 77 functions designed
to solve large scale eigenvalue problems.
The interfaces provided in this module have been chosen to combine ease
of use with the flexibility of the original ARPACK software.
The underlying iterative methods and algorithms remain essentially the
same as those in ARPACK and are described fully in Lehoucq `et al.`
(1998).

The algorithms used in the ARPACK functions are based upon an
algorithmic variant of the Arnoldi process called the Implicitly
Restarted Arnoldi Method.
For symmetric matrices, this reduces to a variant of the Lanczos process
called the Implicitly Restarted Lanczos Method.
These variants may be viewed as a synthesis of the Arnoldi/Lanczos
process with the Implicitly Shifted QR technique that is suitable for
large scale problems.
For many standard problems, a matrix factorization is not required.
Only the action of the matrix on a vector is needed.

The ARPACK functions can be used to find the eigenvalues with the
largest and/or smallest magnitudes, real part or imaginary part.

FEAST Functions
~~~~~~~~~~~~~~~
The functions in this module whose names contain substring '_feast_'
have been derived from the FEAST software suite (see Polizzi (2009)).
FEAST is a general purpose eigensolver for standard, generalized and
polynomial eigenvalue problems.
It is suitable for both sparse and dense matrices, and functions are
available for real, complex, symmetric, Hermitian and non-Hermitian
eigenvalue problems.
The FEAST algorithm requires you to specify a particular region of
interest in the complex plane within which eigenvalues are sought.
The algorithm then performs a numerical quadrature computation,
involving solving linear systems along a complex contour around the
region of interest.

For full information please refer to the NAG Library document

https://www.nag.com/numeric/nl/nagdoc_28.4/flhtml/f12/f12intro.html
"""

# NAG Copyright 2017-2022.

pass
